# test-project

[![Croco Logo](https://i.ibb.co/G5Pjt6M/logo.png)](https://t.me/crocofactory)

The package containing tools to warm up Web3 project using Selenium

- **[Telegram channel](https://t.me/crocofactory)**
- **[Bug reports](https://github.com/blnkoff/test-project/issues)**

Source code is made available under the [MIT License](LICENSE)

# Installing test-project
To install `test-project` from PyPi, you can use that:

```shell
pip install test-project
```

To install `test-project` from GitHub, use that:

```shell
pip install git+https://github.com/blnkoff/test-project.git
```